@@ -5,7 +5,7 @@
 */
 
 #include <config-kitinerary.h>
-#include <knowledgedb/airportdb.h>
+#include "knowledgedb/airportdb.h"
 #include <knowledgedb/timezonedb.cpp>
 
 #include <KItinerary/LocationUtil>
