@@ -44,7 +44,7 @@ function parseLocation(place, addr1, addr2, links)
     const idx = addr1.lastIndexOf(',');
     place.address.streetAddress = addr1.substring(0, idx);
     place.address.addressLocality = addr1.substr(idx + 1);
-    place.geo = JsonLd.toGeoCoordinates(links.shift().url);
+    place.geo = JsonLd.toGeoCoordinates(links.shift()?.url);
 }
 
 function parsePdfTicket(pdf, node, triggerNode)
@@ -63,7 +63,7 @@ function parsePdfTicket(pdf, node, triggerNode)
     let reservations = [];
     while (true) {
         const times = timeColumn.substr(idxTime).match(/(\d\d:\d\d)\n([^:]*?\n)?([^:]*?\n)?(\d\d:\d\d)/);
-        const stations = stationColumn.substr(idxStations).match(/(.*)\n[ ]+(.*)(?:\n|,\n  +(.*)\n)(?:.*(?:NOTE:|Wagennummerierung|platform|The regional part).(?:.*\n)+)?.*(?:Bus|Autobus|Zug|Strecke|Route|Tratta) +(.*)\n.*(?:Direction|à destination de|Kierunek|richting|Richtung|Direzione) (.*)\n(?:.*(?:Operated|Betrieben|Uitgevoerd|Effettuata).*\n)?(.*)\n(?:[ ]+(.*?)(?:\n|,\n +(.*)\n))?/);
+        const stations = stationColumn.substr(idxStations).match(/\b([^].*)\n[ ]+(.*)(?:\n|,\n  +(.*)\n)(?:.*(?:NOTE:|Wagennummerierung|platform|The regional part|Die Bussteignummer).(?:.*\n)+?)?.*(?:Bus|Autobus|Zug|Strecke|Route|Tratta)\s+(\S.+)\n.*(?:Direction|à destination de|Kierunek|richting|Richtung|Direzione) (.*)\n(?:.*(?:Operated|Betrieben|Uitgevoerd|Effettuata).*\n)?(.*)\n(?:[ ]+(.*?)(?:\n|,\n +(.*)\n))?/);
         if (!times || !stations) {
             break;
         }
@@ -130,4 +130,27 @@ function parsePkPass(pass, node) {
     //TODO: Passangier List, Seating
 
     return res
-}
\ No newline at end of file
+}
+
+function parsePkPass2(pass, node) {
+    let res = Object.assign(JsonLd.newBusReservation(), node.result[0]);
+
+    res.reservationFor.departureBusStop.name = pass.primaryFields[0].label;
+    res.reservationFor.departureTime = pass.primaryFields[0].value
+    res.reservationFor.arrivalBusStop = {
+        '@type': 'BusStation',
+        name: pass.primaryFields[1].label
+    };
+    res.reservationFor.arrivalTime = pass.primaryFields[1].value
+
+    res.reservationFor.busNumber = pass.field["transport-type"].value.split(" ")[0]
+    res.reservationFor.busName = pass.field["transport-type"].value
+
+    res.reservationNumber = pass.field["booking-number"].value
+    res.underName.name = pass.field["passenger"].value;
+    res.reservedTicket.ticketedSeat = {
+        '@type': 'Seat',
+        seatNumber: pass.field["seat"].value
+    };
+    return res
+}
