@@ -245,7 +245,7 @@ function parseSecutixPdfItineraryV2(text, res)
     var reservations = new Array();
     var pos = 0;
     while (true) {
-        var data = text.substr(pos).match(/ *(\d+h\d+)\n *(.*)\n *(.*)\n(?: *Voiture (\d+) - Place (\d+)\n.*\n.*\n)? *(\d+h\d+)\n(.*)\n/);
+        var data = text.substr(pos).match(/ *(\d+h\d+)\n *(.*)\n *(.*)\n(?: *Voiture (\d+) - Place (\d+)\n.*\n.*\n)?(?: *Opéré par .*\n)? *(\d+h\d+)\n(.*)\n/);
         if (!data)
             break;
         pos += data.index + data[0].length;
@@ -314,6 +314,10 @@ function parseSecutixPdf(pdf, node, triggerNode)
     for (r of reservations) {
         r.reservationFor.provider = res.reservationFor.provider;
     }
+    for (i in reservations) {
+        if (reservations[i].reservationFor.trainNumber.startsWith("CAR"))
+            reservations[i] = JsonLd.trainToBusReservation(reservations[i]);
+    }
 
     return reservations;
 }
